align 4
KBC_PS2_8042_Keyboard__ScancodeBuffer     times 32 db 0
KBC_PS2_8042_Keyboard__ScancodeBuffer_idx dd 0



KBC_PS2_8042_Mode dd 0  ;0 == keyboard/mouse user input data
                        ;1 == KBC/Keyb/Mouse commands response data



align 4
KBC_PS2_8042_Keyboard__ISR:
 push eax
 push esi
 push edi




;inc byte[0xB8000]



 ;Read one data byte (the actual
 ;meaning of this should also be indicated
 ;by an internal variable that indicates what
 ;is being done -normal data or command results-
 ;and of course by taking steps to perfectly
 ;avoid command/user input data collisions):
 ;;
  in al,0x60
;  cmp byte[executer],1
;  je .END


  cmp al,0xFA
  je .END

  cmp al,0xFE
  je .END

  cmp al,0xAA
  je .END

  cmp al,0xFC
  je .END

  cmp al,0x00
  je .END




 ;Put it into the scan code buffer (which contains
 ;a single scan code sequence):
 ;;
    ;Take the index value:
    ;;
     mov edi,[KBC_PS2_8042_Keyboard__ScancodeBuffer_idx]

    ;Add the buffer base address:
    ;;
     add edi,KBC_PS2_8042_Keyboard__ScancodeBuffer

    ;Save the scan code byte:
    ;;
     stosb

    ;Update the buffer pointing by increasing it and
    ;ANDing it with 31 so it is limited to positions 0-31:
    ;;
     inc dword[KBC_PS2_8042_Keyboard__ScancodeBuffer_idx]
     and dword[KBC_PS2_8042_Keyboard__ScancodeBuffer_idx],11111b



 cmp dword[KBC_PS2_8042_Keyboard__ScancodeBuffer_idx],1
 jne .notFirstScancodeByteReceivedNow
  cmp al,0xE0
  je .END
  cmp al,0xF0
  je .END
 .notFirstScancodeByteReceivedNow:



 cmp dword[KBC_PS2_8042_Keyboard__ScancodeBuffer_idx],2
 jne .notSecondScancodeByteReceivedNow
  cmp al,0xF0
  je .END
 .notSecondScancodeByteReceivedNow:
  


 ;Compare the gathered scan code with all of
 ;the scan codes in the scan code table:
 ;;
  cmp dword[KBC_PS2_8042_Keyboard__ScancodeBuffer_idx],0
  je .bufferEmpty
    call Keyb_Scancode_Compare

  .bufferEmpty:








 ;If we find the scan code, execute the action
 ;it specifies (manipulate LEDs, shift bits,
 ;indicate ASCII character to write...):
 ;;
  







 .END:


 ;Acknowledge IRQ 1:
 ;;
  call PIC_8259__Master_EOI


 pop edi
 pop esi
 pop eax
iret






















Keyb_Scancode_Compare:
 pusha

  ;Take the number of contained scan codes:
  ;;
   mov ecx,0

  ;Go to the start of scan code data:
  ;;
   mov esi,KScanset_2+12

  ;Compare the current contents of the scan code
  ;buffer with the contents of the current scan
  ;code. Iterate:
  ;;
   .l:

    call Keyb_Scancode_Buffer_Scancode_Comparator


  ;See if we found a scan code.
  ;If there was a match, empty the
  ;scan code buffer:
  ;
   cmp eax,1
   jne .noMatch


    jmp .l_END_Match



   .noMatch:
   add esi,ebx


   inc ecx
    ;See how many scan codes there are in
    ;our static scan code table:
    ;;
     cmp ecx,[KScanset_2__ScansetEntries]

    ;If we have run less than the available ones,
    ;keep looking:
    ;;
     jb .l

    ;If we reached or surpassed the limit, end:
    ;;
     jae .END
   .l_END_Match:




    ;Empty the scan code buffer:
    ;;
     mov dword[KBC_PS2_8042_Keyboard__ScancodeBuffer_idx],0


;NOTE: This is almost equivalent to the intrinsic
;      control of our loop above, and so it isn't necessary
;
;    ;If we didn't find the scan code and we
;    ;already got the maximum scan code number
;    ;of bytes, end:
;    ;;
;     cmp ecx,KSCANSET_2_SZ
;     jb .Found
;
;
;        cmp edx,[KScanset_2__LongestScancode]
;        jb .noErase
;
;          mov dword[KBC_PS2_8042_Keyboard__ScancodeBuffer_idx],0
;          jmp .END
;
;
;        .noErase:
;
;
;     .Found:







    ;;;;NOTE: Here we are handling all of the console, but
    ;;;;      it makes our keyboard ISR take more time.
    ;;;;
    ;;;;      We should handle our console either as a separate
    ;;;;      process (when our kernel gets more advanced) or
    ;;;;      just set "console/keyboard events" here and save
    ;;;;      its parameters, so that we process it in the
    ;;;;      "idle loop".
    ;;;;
    ;;;;      In any case, we need either a console/keyboard
    ;;;;      event queue (best) or just make sure to not
    ;;;;      overwrite the "event" data suddenly, when we
    ;;;;      are processing it in the kernel's idle loop and
    ;;;;      IRQs, specially the keyboard ones, keep firing.
    ;;;;
    ;;;;      Probably a way of using it that is faster than
    ;;;;      disabling the keyboard/mouse, and avoid losing
    ;;;;      data from them, would be to just mask the IRQ
    ;;;;      bits at the PIC controllers, or do an equivalent
    ;;;;      thing if we are using an APIC.



    ;WARNING:
    ;Set the states of the keys.
    ;This still needs improvement because
    ;it sets, but does not set, a non-extended
    ;key which has the same Break code than the
    ;Repeat code of an extended key that is
    ;being pressed, so it would not only intervene
    ;the state of the extended key, but also that
    ;of the non-extended key, so we should avoid
    ;that by interpreting escape scan code values,
    ;like 0xF0 and 0xE0.
    ;
    ;Or set single special state positions for all keys that
    ;share identical scan codes, but this very option
    ;would be weak if we want to detect the precise keys
    ;being pressed.
    ;;

     ;First save ECX. Otherwise, we will alter
     ;the right scan code position ID for the
     ;rest of this section of keyboard handling code:
     ;;
      push ecx
      mov esi,Keyboard_KeyStates
      cmp ecx,KSCANSET_2_KNOWN_KEYS
      jae .notMakeRepeatCodes

        add esi,ecx
        mov byte[esi],1
        jmp .keyStateUpdate__END


      .notMakeRepeatCodes:

        ;Convert to key position:
        ;;
         sub ecx,KSCANSET_2_KNOWN_KEYS
         add esi,ecx
         mov byte[esi],0

      .keyStateUpdate__END:


     ;Now we can safely restore our original ECX,
     ;which contains the position in which we found
     ;the scan code, and which represents the lowest
     ;level Make/Repeat/Break key ID as a value
     ;standarized by our kernel:
     ;;
      pop ecx



    ;If the scancode was found at positions 0-62,
    ;it is an alphanumeric character. Use an ASCII
    ;table to gather an ASCII char, and print it:
    ;;
     mov esi,Keyboard_KeyStates
     cmp ecx,63
     ja .notAlphaNumSetCode

          cmp byte[esi+67],1    ;Is left shift pressed?
          je .shift
          cmp byte[esi+68],1    ;Is right shift pressed?
          je .shift
           mov esi,KB_ASCII_Print_Table

           jmp .shifter_end

          .shift:

           mov esi,KB_ASCII_Shift_Print_Table


          .shifter_end:



         add esi,ecx
         mov al,[esi]
          call console__put_cmdline_ASCII_char


     .notAlphaNumSetCode:




    ;ENTER or KeyPad ENTER:
    ;;
     cmp ecx,64
     je .doENTER
     cmp ecx,65
     jne .noENTER

      .doENTER:

       ;v2012-06-26:
       ;  For more ease of use, convert the character right after
       ;  the end of the command line into an ASCIIZ null char:
       ;;
        mov esi,console_command_line
        mov ebx,[console_command_line_idx]
        mov byte[esi+ebx],0




       mov byte[executer],1   ;Send an 'execute command line message'
       jmp .END

     .noENTER:


    ;Backspace:
    ;;
     cmp ecx,66
     jne .noBacksp
        call console_erase_char

     .noBacksp:


    ;Check is a Ctrl+Alt+Del combination
    ;is being pressed to reset the system
    ;by using the KBC:
    ;;
     call System_Reset_Test_Loop



    ;See if we are dealing with Scroll/Caps/Num Lock:
    ;;
     call k_leds


     .noleds:


      

 .END:


 popa
ret






;Inputs:
;      ESI == Start address of the current scan code entry
;
;Outputs:
;      EAX == 1 if the current scan code matched; 0 if not.
;      EBX == Number of bytes to skip for the next possible
;             scan code entry, taking into account the length
;             byte and the scan code bytes for the current entry.
;;
Keyb_Scancode_Buffer_Scancode_Comparator:
 push ecx
 push edx
 push esi
 push edi


  ;Assume that the scan code didn't match:
  ;;
   xor eax,eax

  ;Take the current length of the buffer:
  ;;
   mov ebx,[KBC_PS2_8042_Keyboard__ScancodeBuffer_idx]

  ;Take the length of the current scan code:
  ;;
   xor ecx,ecx
   mov cl,[esi]
   mov edx,ecx

  ;See if both lengths match. If not, it means that
  ;the current scan code from the table cannot match
  ;the current scan code in the buffer:
  ;;
   cmp ecx,ebx
   jbe .lengthMatch
    ;This will effectively end with a no-match
    ;condition:
    ;;
     jmp .END

   .lengthMatch:


   ;If lengths matched, use the length in ECX
   ;to iterate:
   ;;
     ;Take the start of the buffer. This will compare
     ;both the buffer with the current scan code entry:
     ;in the scan code table:
     ;;
      inc esi
      mov edi,KBC_PS2_8042_Keyboard__ScancodeBuffer


      .l:
        cmpsb
        jne .l_END

       dec ecx
       jnz .l
      .l_END:




     ;If ECX is not 0, it means that we ended before comparing
     ;all characters, which means that the scan code didn't match
      cmp ecx,0
      jnz .noMatch

       ;If we are here, it means that the scan code
       ;matched, and we will report that:
        mov eax,1
        jmp .END


      .noMatch:



 xor eax,eax


 .END:

   mov ebx,edx     ;Number of bytes to skip
   inc ebx         ;Skip the count byte


 pop edi
 pop esi
 pop edx
 pop ecx
ret


executer db 0
