;NOTE: The order in which the scan codes have been put
;      in this table is "arbitrary", but it has become
;      a standard position, dictated by my most urgent
;      key needs.
;
;      For all printable keys, the Make codes are grouped
;      together, and there are Repeat codes, if any, and
;      Break codes in separate "groups". In this way, we
;      tend to need no padding in our printable ASCII tables
;      for non-printable scan code positioned at interwined
;      locations with those scan codes that are printable.
;
;      It means that the current format of this table should
;      be followed, unless the sequence that our driver takes
;      changes altogether.
;
;      We would also need to have a second table, in which
;      each byte position should represent the state of the
;      key:
;              0 --- Not pressed
;              1 --- Pressed
;    (possibly 2 --- Repeating)
;
;       But before that, we need to fully define all of the
;       standard Make/Repeat/Break codes, and a means to add
;       nonstandard key functionality.
;
;       We should have a central function that sets the state
;       of each key position, every time we recognize a scan code,
;       and then, based on their static, standarized positions or
;       position ranges, perform the default action, or any other
;       action, calling the appropriate functions.
;
;       We could have a third table, an "overlay" table, that would
;       contain, say, QWORDs at 0 as a default for every key, and
;       that would contain a non-zero value, an function's entry point
;       value, for overrided functionality of a key.
;
;       This model lends itself naturally to record Shift/Alt/Ctrl
;       states, and to detect the raw press of any keys, printable
;       or not, if we wish to use such states instead of the characters
;       or default actions those keys produce.


;If a key only has a Make code, or if it has a Repeat code,
;we will treat a different Repeat code as a "different" key
;press in the Make codes group, and in the Break codes group,
;we will place a dummy scan code, with length of 0 and without
;scan code data bytes, to make this table and both of their
;groups symetric.


align 4
KScanset_2:

KSCANSET_2_KNOWN_KEYS equ (36+12+15+1+2+1+6+1+3)
        KSCANSET_2_SZ equ KSCANSET_2_KNOWN_KEYS*2


KScanset_2__ScansetNumber   dd 2
KScanset_2__LongestScancode dd 8
KScanset_2__ScansetEntries  dd KSCANSET_2_SZ








  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
   ;These keys have the same codes for make and
   ;for Repeat:
   ;;
         db 1
         db 0x1C      ;A -- Make(0)

         db 1
         db 0x32      ;B -- Make(1)

         db 1
         db 0x21      ;C -- Make(2)

         db 1
         db 0x23      ;D -- Make(3)

         db 1
         db 0x24      ;E -- Make(4)

         db 1
         db 0x2B      ;F -- Make(5)

         db 1
         db 0x34      ;G -- Make(6)

         db 1
         db 0x33      ;H -- Make(7)

         db 1
         db 0x43      ;I -- Make(8)

         db 1
         db 0x3B      ;J -- Make(9)

         db 1
         db 0x42      ;K -- Make(10)

         db 1
         db 0x4B      ;L -- Make(11)

         db 1
         db 0x3A      ;M -- Make(12)

         db 1
         db 0x31      ;N -- Make(13)

         db 1
         db 0x44      ;O -- Make(14)

         db 1
         db 0x4D      ;P -- Make(15)

         db 1
         db 0x15      ;Q -- Make(16)

         db 1
         db 0x2D      ;R -- Make(17)

         db 1
         db 0x1B      ;S -- Make(18)

         db 1
         db 0x2C      ;T -- Make(19)

         db 1
         db 0x3C      ;U -- Make(20)

         db 1
         db 0x2A      ;V -- Make(21)

         db 1
         db 0x1D      ;W -- Make(22)

         db 1
         db 0x22      ;X -- Make(23)

         db 1
         db 0x35      ;Y -- Make(24)

         db 1
         db 0x1A      ;Z -- Make(25)

         db 1
         db 0x16      ;1 -- Make(26)

         db 1
         db 0x1E      ;2 -- Make(27)

         db 1
         db 0x26      ;3 -- Make(28)

         db 1
         db 0x25      ;4 -- Make(29)

         db 1
         db 0x2E      ;5 -- Make(30)

         db 1
         db 0x36      ;6 -- Make(31)

         db 1
         db 0x3D      ;7 -- Make(32)

         db 1
         db 0x3E      ;8 -- Make(33)

         db 1
         db 0x46      ;9 -- Make(34)

         db 1
         db 0x45      ;0 -- Make(35)



  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
   ;These keys have the same codes for make and
   ;for Repeat:
   ;;
         db 1
         db 0x0E      ;` -- Make(36)

         db 1
         db 0x4E      ;- -- Make(37)

         db 1
         db 0x55      ;= -- Make(38)

         db 1
         db 0x5D      ;\ -- Make(39)

         db 1
         db 0x54      ;[ -- Make(40)

         db 1
         db 0x5B      ;] -- Make(41)

         db 1
         db 0x4C      ;; -- Make(42)

         db 1
         db 0x52      ;' -- Make(43)

         db 1
         db 0x41      ;, -- Make(44)

         db 1
         db 0x49      ;. -- Make(45)

         db 1
         db 0x4A      ;/ -- Make(46)

         db 1
         db 0x29      ;SpaceBar -- Make(47)









  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
         db 2
         db 0xE0,0x4A      ;/ -- Make(48)

         db 1
         db 0x7C           ;* -- Make/Repeat(49)

         db 1
         db 0x7B           ;- -- Make/Repeat(50)

         db 1
         db 0x79           ;+ -- Make/Repeat(51)

         db 1
         db 0x71           ;. -- Make/Repeat(52)

         db 1
         db 0x70           ;0 -- Make/Repeat(53)

         db 1
         db 0x69           ;1 -- Make/Repeat(54)

         db 1
         db 0x72           ;2 -- Make/Repeat(55)

         db 1
         db 0x7A           ;3 -- Make/Repeat(56)

         db 1
         db 0x6B           ;4 -- Make/Repeat(57)

         db 1
         db 0x73           ;5 -- Make/Repeat(58)

         db 1
         db 0x74           ;6 -- Make/Repeat(59)

         db 1
         db 0x6C           ;7 -- Make/Repeat(60)

         db 1
         db 0x75           ;8 -- Make/Repeat(61)

         db 1
         db 0x7D           ;9 -- Make/Repeat(62)







  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
         db 1
         db 0x61      ;< -- Make/Repeat(63)





  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
   ;The normal ENTER has the same code for Make and
   ;for Repeat.
   ;;
         db 1
         db 0x5A           ;Enter -- Make(64)


   ;The keypad ENTER has the following code for Make,
   ;the code above for Repeat, and "escaped" code for
   ;"break".
   ;;
         db 2
         db 0xE0,0x5A      ;Keypad Enter -- Make(65)






  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
         db 1
         db 0x66      ;Back Space -- Make(66)













  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
         db 1
         db 0x12      ;Left Shift -- Make/Repeat(67)

         db 1
         db 0x59      ;Right Shift -- Make/Repeat(68)

         db 1
         db 0x14      ;Left Ctrl -- Make/Repeat(69)

         db 2
         db 0xE0,0x14 ;Right Control -- Make(70)

         db 1
         db 0x11      ;Left Alt -- Make/Repeat(71)

         db 2
         db 0xE0,0x11 ;Right Alt (Alt Gr.) -- Make(72)







  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
         db 4
         db 0xE0,0x12,0xE0,0x71      ;Del -- Make(73)






  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
         db 1
         db 0x58         ;Caps Lock -- Make/Repeat(74)

         db 1
         db 0x77         ;Num Lock -- Make/Repeat(75)

         db 1
         db 0x7E         ;Scroll Lock -- Make/Repeat(76)
















;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;








  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
  ;;;;;;;;;;;;Alphanumeric Keys (36);;;;;;;;;;;;
   ;These keys have the same codes for make and
   ;for Repeat:
   ;;
         db 2
         db 0xF0,0x1C      ;A -- Break(0)

         db 2
         db 0xF0,0x32      ;B -- Break(1)

         db 2
         db 0xF0,0x21      ;C -- Break(2)

         db 2
         db 0xF0,0x23      ;D -- Break(3)

         db 2
         db 0xF0,0x24      ;E -- Break(4)

         db 2
         db 0xF0,0x2B      ;F -- Break(5)

         db 2
         db 0xF0,0x34      ;G -- Break(6)

         db 2
         db 0xF0,0x33      ;H -- Break(7)

         db 2
         db 0xF0,0x43      ;I -- Break(8)

         db 2
         db 0xF0,0x3B      ;J -- Break(9)

         db 2
         db 0xF0,0x42      ;K -- Break(10)

         db 2
         db 0xF0,0x4B      ;L -- Break(11)

         db 2
         db 0xF0,0x3A      ;M -- Break(12)

         db 2
         db 0xF0,0x31      ;N -- Break(13)

         db 2
         db 0xF0,0x44      ;O -- Break(14)

         db 2
         db 0xF0,0x4D      ;P -- Break(15)

         db 2
         db 0xF0,0x15      ;Q -- Break(16)

         db 2
         db 0xF0,0x2D      ;R -- Break(17)

         db 2
         db 0xF0,0x1B      ;S -- Break(18)

         db 2
         db 0xF0,0x2C      ;T -- Break(19)

         db 2
         db 0xF0,0x3C      ;U -- Break(20)

         db 2
         db 0xF0,0x2A      ;V -- Break(21)

         db 2
         db 0xF0,0x1D      ;W -- Break(22)

         db 2
         db 0xF0,0x22      ;X -- Break(23)

         db 2
         db 0xF0,0x35      ;Y -- Break(24)

         db 2
         db 0xF0,0x1A      ;Z -- Break(25)

         db 2
         db 0xF0,0x16      ;1 -- Break(26)

         db 2
         db 0xF0,0x1E      ;2 -- Break(27)

         db 2
         db 0xF0,0x26      ;3 -- Break(28)

         db 2
         db 0xF0,0x25      ;4 -- Break(29)

         db 2
         db 0xF0,0x2E      ;5 -- Break(30)

         db 2
         db 0xF0,0x36      ;6 -- Break(31)

         db 2
         db 0xF0,0x3D      ;7 -- Break(32)

         db 2
         db 0xF0,0x3E      ;8 -- Break(33)

         db 2
         db 0xF0,0x46      ;9 -- Break(34)

         db 2
         db 0xF0,0x45      ;0 -- Break(35)



  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
  ;;;;;;;;;;;;Symbolic Keys (12);;;;;;;;;;;;
   ;These keys have the same codes for make and
   ;for Repeat:
   ;;
         db 2
         db 0xF0,0x0E      ;` -- Break(36)

         db 2
         db 0xF0,0x4E      ;- -- Break(37)

         db 2
         db 0xF0,0x55      ;= -- Break(38)

         db 2
         db 0xF0,0x5D      ;\ -- Break(39)

         db 2
         db 0xF0,0x54      ;[ -- Break(40)

         db 2
         db 0xF0,0x5B      ;] -- Break(41)

         db 2
         db 0xF0,0x4C      ;; -- Break(42)

         db 2
         db 0xF0,0x52      ;' -- Break(43)

         db 2
         db 0xF0,0x41      ;, -- Break(44)

         db 2
         db 0xF0,0x49      ;. -- Break(45)

         db 2
         db 0xF0,0x4A      ;/ -- Break(46)

         db 2
         db 0xF0,0x29      ;SpaceBar -- Break(47)









  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
  ;;;;;;;;;;;;Keypad Keys (15);;;;;;;;;;;;
         db 3
         db 0xE0,0xF0,0x4A      ;/ -- Break(48)

         db 2
         db 0xF0,0x7C           ;* -- Break(49)

         db 2
         db 0xF0,0x7B           ;- -- Break(50)

         db 2
         db 0xF0,0x79           ;+ -- Break(51)

         db 2
         db 0xF0,0x71           ;. -- Break(52)

         db 2
         db 0xF0,0x70           ;0 -- Break(53)

         db 2
         db 0xF0,0x69           ;1 -- Break(54)

         db 2
         db 0xF0,0x72           ;2 -- Break(55)

         db 2
         db 0xF0,0x7A           ;3 -- Break(56)

         db 2
         db 0xF0,0x6B           ;4 -- Break(57)

         db 2
         db 0xF0,0x73           ;5 -- Break(58)

         db 2
         db 0xF0,0x74           ;6 -- Break(59)

         db 2
         db 0xF0,0x6C           ;7 -- Break(60)

         db 2
         db 0xF0,0x75           ;8 -- Break(61)

         db 2
         db 0xF0,0x7D           ;9 -- Break(62)





  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Extra Printable Keys (1);;;;;;;;;;;;
         db 2
         db 0xF0,0x61      ;< -- Break(69)





  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
  ;;;;;;;;;;;;ENTER Keys (2);;;;;;;;;;;;
   ;The normal ENTER has the same code for Make and
   ;for Repeat.
   ;;
         db 2
         db 0xF0,0x5A           ;Enter -- Break(48)


   ;The keypad ENTER has the following code for Make,
   ;the code above for Repeat, and "escaped" code for
   ;"break".
   ;;
         db 3
         db 0xE0,0xF0,0x5A      ;Keypad Enter -- Break(49)






  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;"Format" Keys (1);;;;;;;;;;;;
         db 2
         db 0xF0,0x66      ;Back Space -- Break(50)













  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
  ;;;;;;;;;;;;Control Keys (6);;;;;;;;;;;;
         db 2
         db 0xF0,0x12      ;Left Shift -- Break(51)

         db 2
         db 0xF0,0x59      ;Right Shift -- Break(52)

         db 2
         db 0xF0,0x14      ;Left Ctrl -- Break

         db 3
         db 0xE0,0xF0,0x14 ;Right Control -- Break

         db 2
         db 0xF0,0x11      ;Left Alt -- Break

         db 3
         db 0xE0,0xF0,0x11 ;Right Alt (Alt Gr.) -- Break








  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
  ;;;;;;;;;;;;Displacement/Text manipulation Keys (1);;;;;;;;;;;;
         db 6
         db 0xE0,0xF0,0x71,0xE0,0xF0,0x12      ;Del -- Break(53)








  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
  ;;;;;;;;;;;;Standard LED Keys (3);;;;;;;;;;;;
         db 2
         db 0xF0,0x58    ;Caps Lock -- Break(70)

         db 2
         db 0xF0,0x77    ;Num Lock -- Break(71)

         db 2
         db 0xF0,0x7E    ;Scroll Lock -- Break(72)
