;This function can handle the following KBC commands:
;
;0x60
;0xD1
;
;Interrupts must be enabled before calling this function,
;since it needs basic PIT timing functions for timeout errors.
;
;Inputs:
;       AL == Command
;       AH == Parameter
;
;;
KBC_PS2_8042__send_2partCmd_withNoResults:


 ;Wait for the Input Port of the KBC to be
 ;ready for command writing:
 ;; 
  call KBC_PS2_8042__waitUntilCommandable


 ;Check that no errors occurred:
 ;;
  cmp dword[KBC_PS2_8042__LastError],0

 ;If there was an error (KBC_PS2_8042__LastError
 ;is not 0), we should carefuly end this function:
 ;;
  jne .KBC_PS2_8042__send_2partCmd_withNoResults__endWithError


 ;If we are here, everything was OK, and we must write
 ;the command value:
 ;;
  out 0x64,al

 ;Now we must wait again for the Input Port of the
 ;KBC to be ready for the second, and final command byte:
 ;;
  call KBC_PS2_8042__waitUntilCommandable


 ;Check again that no errors occurred:
 ;;
  cmp dword[KBC_PS2_8042__LastError],0

 ;If there was an error the second time (KBC_PS2_8042__LastError
 ;is not 0), we should carefuly end this function:
 ;;
  jne .KBC_PS2_8042__send_2partCmd_withNoResults__endWithError


 ;If we are here, everything was OK, and we must write
 ;the second byte, the parameter byte:
 ;;
  ror ax,8
  out 0x60,al
  ror ax,8    ;Set AX to its original state



 ;Done.




 .KBC_PS2_8042__send_2partCmd_withNoResults__endWithError:

ret



































KBC_PS2_8042__waitUntilCommandable:
 push eax
 push ebx
 push ecx


  ;Clear the KBC errors:
  ;;
   mov dword[KBC_PS2_8042__LastError],0



  ;Set a maximum timeout of
  ;approximately 100 miliseconds:
  ;;
   mov ebx,100



   .waitUntilReady:
    ;See if we can write already the Input
    ;Buffer of the KBC to send commands.
    ;If so, end:
    ;;
     in al,0x64
     test al,00000010b
     jz .waitUntilReady__END


    ;If we are here, it means that the Input
    ;Buffer of the KBC was not ready, and we will
    ;wait up to 100 miliseconds, in groups of 2
    ;miliseconds, to be able to check the status
    ;of the Input Port every 2 miliseconds:
    ;;
      ;ECX == Number of ticks to wait.
      ;;
       mov ecx,2
       call PIT_8253_4__waitTickChanges

      ;Discount 2 more miliseconds:
      ;;
       sub ebx,2

      ;If we didn't time out, continue:
      ;;
       jnz .waitUntilReady

      ;If we timed out, end (with error):
      ;;
       mov dword[KBC_PS2_8042__LastError],KBC_PS2_8042__LastError__InputBuffTimeoutErr
       jmp .waitUntilReady__END



   jmp .waitUntilReady
   .waitUntilReady__END:


 pop ecx
 pop ebx
 pop eax
ret
































KBC_PS2_8042__disableMouse:
 push eax

 ;It just disables IRQ12 in the
 ;Slave PIC to avoid having to
 ;send many commands to the KBC/Mouse/Keyboard.
 ;
 ;We should probably, however we choose to use to disable
 ;the Mouse, etc., avoid doing that in the middle
 ;of a mouse packet:
 ;
  in al,0xA1
  or al,00010000b
  out 0xA1,al


 pop eax
ret






KBC_PS2_8042__enableMouse:
 push eax

 ;It just enables IRQ12 in the
 ;Slave PIC to avoid having to
 ;send many commands to the KBC/Mouse/Keyboard:
 ;
  in al,0xA1
  and al,11101111b
  out 0xA1,al


 pop eax
ret









KBC_PS2_8042__disableKeyboard:
 push eax

 ;It just disables IRQ1 in the
 ;Slave PIC to avoid having to
 ;send many commands to the KBC/Mouse/Keyboard.
 ;
 ;We should probably, however we choose to use to disable
 ;the Mouse, etc., avoid doing that in the middle
 ;of a scan code sequence:
 ;
  in al,0x21
  or al,00000010b
  out 0x21,al


 pop eax
ret






KBC_PS2_8042__enableKeyboard:
 push eax

 ;It just enables IRQ1 in the
 ;Slave PIC to avoid having to
 ;send many commands to the KBC/Mouse/Keyboard:
 ;
  in al,0xA1
  and al,11111110b
  out 0xA1,al


 pop eax
ret











KBC_PS2_8042__disableKeyboardMouse:
 push eax


 ;It just disables IRQ1 in the
 ;Slave PIC to avoid having to
 ;send many commands to the KBC/Mouse/Keyboard.
 ;
 ;We should probably, however we choose to use to disable
 ;the Mouse, etc., avoid doing that in the middle
 ;of a scan code sequence:
 ;
  in al,0x21
  or al,00000010b
  out 0x21,al


 ;It just disables IRQ12 in the
 ;Slave PIC to avoid having to
 ;send many commands to the KBC/Mouse/Keyboard.
 ;
 ;We should probably, however we choose to use to disable
 ;the Mouse, etc., avoid doing that in the middle
 ;of a mouse packet:
 ;
  in al,0xA1
  or al,00010000b
  out 0xA1,al


 pop eax
ret

















KBC_PS2_8042__enableKeyboardMouse:
 push eax


 ;It just enables IRQ1 in the
 ;Slave PIC to avoid having to
 ;send many commands to the KBC/Mouse/Keyboard:
 ;
  in al,0xA1
  and al,11111110b
  out 0xA1,al


 ;It just enables IRQ12 in the
 ;Slave PIC to avoid having to
 ;send many commands to the KBC/Mouse/Keyboard:
 ;
  in al,0xA1
  and al,11101111b
  out 0xA1,al


 pop eax
ret







































kbc_waitUntilCommandable:
 push eax


  .waitUntilReady:
    in al,0x64
    test al,00000010b
  jnz .waitUntilReady


 pop eax
ret


kbc_waitForDataForUs:
 push eax


  .waitUntilReady:
     in al,0x64
  test al,00000001b
  jz .waitUntilReady


 pop eax
ret
