;This function just waits for the specified
;number of times that the ticks variable of
;the PIT ISR takes a different value. This
;function locks up the execution of everything
;else, so the recommendation is to:
;
;- Use an overall value of numTicksToWait+1
;
;- If the delay is very long (more than 100 ticks), it
;  would be better to wait, say 50 times, split
;  in groups of 2 ticks, and thus we won't
;  lock up everything else. This is the simplest
;  way of waiting an approximate number of
;  miliseconds reliably without locking.
;
;NOTE: If interrupts are disabled at the time we call
;      this function, we will never return from this
;      function.
;
;
;Inputs:
;      ECX == Number of ticks to wait.
;;
 align 4
 PIT_8253_4__waitTickChanges:
  push eax
  push ebx
  push ecx

   ;Take the current value of ticks:
   ;;
    mov eax,[_____8253PIT__ticksSinceSystemStart]

   ;Create a comparison value so we can start
   ;with the detection of a "no-change" condition
   ;to stay in the wait loop:
   ;;
    mov ebx,eax



   ;Start a loop to evaluate the number
   ;of changes:
   ;;
    .l:

      ;Re-read the ticks variable:
      ;;
       mov eax,[_____8253PIT__ticksSinceSystemStart]


      ;See if the timer has changed:
      ;;
       cmp eax,ebx

      ;If not, continue:
      ;;
       je .l


      ;If we are here we changed. So we must
      ;take a double copy of the new tick value
      ;for a new "no-change" condition, to keep
      ;staying in the loop, and we also must discount
      ;1 more tick:
      ;;
       mov ebx,eax
       dec ecx
       jz .l_end   ;If no ticks to wait are left, we finish.



    jmp .l
    .l_end:


  pop ecx
  pop ebx
  pop eax
 ret
