;Read a binary file from FAT12 and execute it:
;
;
;Inputs:
;       ESI = String with the raw 11-byte, 8.3 file name
;
;
;Outputs:
;        EAX = Program loaded
;          0 = Not loaded/not found
;          1 = Program file found and loaded
;;
FAT12_execExternalProgram:
 push ebx
 push ecx
 push edx
 push esi
 push edi

  xor eax,eax


  call FDC_TurnOnFloppyA_1_44
  call FDC_RecalibrateFloppyA_1_44





  ;First, we must read the FAT12 table
  ;and cache it in memory; otherwise
  ;we will be reading garbage:
  ;;
   call createFATcache


  ;Search our file entry, to "convert"
  ;it from a plain file name, to its
  ;initial cluster position:
  ;;
   ;mov esi,program_filename_8_3_FAT12
   call FAT12_find_8_3_FileEntry



  ;If the initial cluster number is 0,
  ;it means that we didn't find the file
  ;and we must avoid running the rest
  ;of this function, so we just return
  ;from it:
  ;;
   cmp dword[FAT12_currentCluster],0
   je .end;



  ;Read the first sector cluster of the file,
  ;to figure out where in memory to load the program:
  ;;
   mov ebx,[FAT12_currentCluster]
   call FAT12_cluster2lba
   call FDC_readSector_LBAFloppyA_1_44



  ;Read our file contents in the
  ;physical address pointed to by the
  ;first DWORD/QWORD in the file we are
  ;reading:
  ;;
;;   mov edi,[Floppy_Sector_Cache]
;   mov edi,[0]
   mov edi,[Floppy_Sector_Cache_Start]
   mov edi,[edi+RawEXE__IntendedBaseAddress]
   call FAT12_readFullFileClusterChain


  ;If we didn't read any sectors,
  ;also we must end to avoid executing
  ;garbage:
  ;;
   cmp ecx,0
   je .end


   ;If we are here, just execute
   ;the loaded program, by calling
   ;it:
   ;;
    call FDC_TurnOffFloppyA_1_44


   ;Fix the different "linking" variables in the
   ;executable image in memory:
   ;;
    mov dword[edi+RawEXE__CommandLinePtr],console_command_line
    mov dword[edi+RawEXE__CommandLineLength],console_command_line_idx
    mov dword[edi+RawEXE__CommandLineParamsPtr],console_command_params_ptr
    mov dword[edi+RawEXE__KernelFnExportsTable],Kernel_Exported_Functions_Table
    mov dword[edi+RawEXE__KernelVrExportsTable],Kernel_Exported_Variables_Table


    ;Convert the import reference function numbers to
    ;WIDEWORD entry point addresses to be able to do simple
    ;calls to the imported functions without compromising
    ;registers or stack set up.
    ;
    ;NOTE: This was previously done by the application, but now it depends on the kernel,
    ;      so that our program requires less work, less imported/duplicated
    ;      code, and having to do this setup right here, just like Windows and
    ;      Linux would do at dynamic linking time.
    ;;
     mov esi,[edi+RawEXE__AppFnImportsTable]
      call resolveFunctionReferences



    add edi,RawEXE__EntryPoint    ;Skip the executable loading data




    ;I currently don't know of a better way to preserve registers
    ;as for our current kernel, so I will just save them before calling
    ;the loaded application, and restore them after returning from the
    ;application:
    ;;
     push eax
     push ebx
     push ecx
     push edx
     push esi
     push edi
     push ebp
      call edi
     pop ebp
     pop edi
     pop esi
     pop edx
     pop ecx
     pop ebx
     pop eax



    mov eax,1       ;Mark "Program Found and Loaded"
    jmp .endOK


  .end:
  call FDC_TurnOffFloppyA_1_44
  mov eax,0    ;Mark "Program Not Found/Not Loaded"






 .endOK:


 pop edi
 pop esi
 pop edx
 pop ecx
 pop ebx
ret
