;Inputs:
;
;ESI = 11-byte binary ASCII file name buffer
;
;Outputs:
;      FAT12_currentCluster -- stores
;      the initial cluster number in this
;      32-bit variable. If the file was not
;      found (in the root directory) this
;      variable will contain 0.
;
;;
FAT12_find_8_3_FileEntry:
 push eax
 push ebx
 push ecx
 push esi
 push edi


 ;Mark file as not found:
 ;;
  mov dword[FAT12_currentCluster],0





  ;EDI = string
  ;
  ;Convert string of the searched for
  ;file name to uppercase, in which
  ;short file names are ALWAYS stored in:
  ;
  ;;
   mov edi,esi
   call FAT_lowercase2uppercase




 ;We will look the file in the
 ;14 root directory sectors:
 ;;

 ;EBX = LBA sector of start of root dir
 ;      (sector 19)
 ;
 ;;
  mov ebx,FAT12_rootDir_LBA_start


 ;Root dir sector count (14 sectors):
 ;;
  mov ecx,FAT12_rootDir_LBA_sectorCount




  .l:

    ;Read the sector:
    ;;
     call FDC_readSector_LBAFloppyA_1_44


    ;Traverse all entries of this sector
    ;for the file:
    ;;
     call FAT12_find_8_3_FileEntry_32by32

    ;If EAX is not -1, it means we found
    ;the file, and we must end this very
    ;loop:
    ;;
     cmp eax,-1
     jnz .l_end



    ;If the file was not found,
    ;read the next sector:
    ;;
     inc ebx
  dec ecx
  jnz .l
  .l_end:



  ;If EAX is not -1, it means we found
  ;the file, and we must end this very
  ;loop:
  ;;
   cmp eax,-1
   jz .fileNotFound

     ;Update EDI to free up
     ;EAX:
     ;;
      mov edi,eax

     ;Now, we will read the 2-byte WORD
     ;at offset 26 of the current file
     ;entry, but ONLY if the attribute
     ;at byte offset 11 is 0x20:
     ;;
      cmp byte[edi+11],0x20
      je .archiveAttributeOK

;        ;Mark file as not found:
;        ;;
;         mov dword[FAT12_currentCluster],0
         jmp .fileNotFound


      .archiveAttributeOK:


      ;If we found everything OK, save the
      ;initial cluster, at offset 26, in
      ;our internal 32-bit variable:
      ;;
       xor eax,eax
       mov ax,[edi+26]
       mov dword[FAT12_currentCluster],eax


   .fileNotFound:


 pop edi
 pop esi
 pop ecx
 pop ebx
 pop eax
ret















;Inputs:
;
;ESI = 11-byte binary ASCII file name buffer
;
;
;Outputs:
;
;EAX = Offset of the file name in the
;      512-byte sector. If it was not
;      found, it will contain -1.
;;
FAT12_find_8_3_FileEntry_32by32:
 push ecx
 push edi




  ;Point to the 512-byte DMA floppy
  ;sector buffer, currently at physical
  ;address 0:
  ;;
   mov edi,[Floppy_Sector_Cache_Start]



  ;Prepare 16 entries per sector:
  ;;
   mov ecx,(512/32)



  .l:

   ;See if the current file name entry
   ;in the root directory matches.
   ;If it does, return the offset
   ;in EAX:
   ;;
    call FAT_compare_8_3_name_match

    ;If we found the file, break the
    ;loop immediately, with the correct
    ;offset value in EAX. In any other
    ;cases, where the file is not found,
    ;EAX will contain -1
    ;;
     cmp eax,-1   
     jnz .l_end


  add edi,32  ;Go to next entry
  dec ecx     ;One less entry to go...
  jnz .l
  .l_end:




 pop edi
 pop ecx
ret












;ESI = searched-for 11-byte file name
;EDI = currently processed entry offset
;
;Outputs:
;
;EAX = Will contain the current entry offset
;      from EDI, if the file was found.
;
;      If the file was not found, it will
;      contain -1.
;
;;
FAT_compare_8_3_name_match:
 push ebx
 push ecx
 push esi
 push edi
 push ebp


 ;Store a copy of EDI in EBP:
 ;;
  mov ebp,edi


 ;Assume the file name doesn't
 ;match:
 ;;
  mov eax,-1


 ;Load processing for 11 characters:
 ;;
  mov ecx,11


  .l:

    ;Compare the current character pair,
    ;and if it doesn't match, return with
    ;no-match condition (EAX=-1):
    ;;
     mov bl,[esi]
     mov bh,[edi]
     cmp bl,bh
     jnz .l_end_noMatch



    ;Advance to next character pair:
    ;;
     inc esi
     inc edi

  ;One less character left...
  ;;
   dec ecx
  jnz .l


    ;If we are here, it means we
    ;traversed all 11 characters, and
    ;all of them matched, so we set
    ;EAX to the current entry offset
    ;to show that the file
    ;name matched in the current
    ;root directory entry:
    ;;
     mov eax,ebp


  .l_end_noMatch:


 pop ebp
 pop edi
 pop esi
 pop ecx
 pop ebx
ret
