;This function takes the cluster
;at FAT12_currentCluster, and
;changes its value continuously,
;until it finds the EOF cluster
;value of 0x0FFF:
;
;Inputs:
;
;      EDI = destination physical memory
;            address
;
;Outputs:
;
;      ECX = Sectors read
;;
FAT12_readFullFileClusterChain:
 push eax
 push ebx
 push edi

 ;Put the sector count to 0:
 ;;
  xor ecx,ecx


 ;Take the initial cluster:
 ;;
  mov ebx,[FAT12_currentCluster]


 ;If the cluster value is 0x0FFF,
 ;it means that there's nothing more
 ;to read, and thus we break this loop:
 ;;
  cmp bx,0x0FFF
  je .l_end





 .l:
  ;Read the corresponding cluster
  ;sector to its final destination,
  ;advance the final destination's
  ;pointer, and account for one more
  ;sector read in ECX:
  ;;
   call FAT12_readLBAdata
   add edi,512
   inc ecx


  ;Convert the cluster number to a raw
  ;offset into the FAT, which corresponds
  ;exclusively and statically to this
  ;cluster number. We get it in EAX:
  ;;
   call FAT12_cluster2fatEntry


  ;Read that position to get the next/new
  ;cluster number to read. We get it in EBX:
  ;;
   call FAT12_readFATentry


  ;If the cluster value is 0x0FFF,
  ;it means that there's nothing more
  ;to read, and thus we break this loop:
  ;;
   cmp bx,0x0FFF
   je .l_end


 ;Keep looping, to read the next
 ;sectors, if any:
 ;;

 jmp .l
 .l_end:



 pop edi
 pop ebx
 pop eax
ret










;This function reads a sector
;that corresponds to a cluster
;in the floppy data area.
;
;Inputs:
;
;    EBX = Cluster number (from 2)
;    EDI = Destination memory for LBA sector
;
FAT12_readLBAdata:
 push ebx
 push ecx
 push esi
 push edi


  ;Convert the cluster to LBA
  ;address. We get the LBA in EBX:
  ;;
   call FAT12_cluster2lba



  ;Read the LBA sector:
  ;;
   call FDC_readSector_LBAFloppyA_1_44


  ;Copy sector, from its internal
  ;software DMA buffer, to its final
  ;destination pointed to by EDI:
  ;;
;      xor esi,esi        ;sourceMem
;;     mov esi,Floppy_Sector_Cache        ;sourceMem
   mov esi,[Floppy_Sector_Cache_Start]

   ;mov edi,edi        ;destinMem
    mov cx,512         ;memLength
     call kmemcpy




 pop edi
 pop esi
 pop ecx
 pop ebx
ret











;This function takes a cluster
;number (starting at 2) and converts
;it into its corresponding raw byte offset
;entry into the FAT table, to read
;the chain:
;
;This function does NOT actually read
;the value of that next entry, but just
;returns its offset.
;
;Inputs:
;
;      EBX = cluster number
;
;Outputs:
;      EAX = FAT entry offset
;;
FAT12_cluster2fatEntry:

  ;Multiply the cluster number by 1.5,
  ;or in this case, its equivalent of
  ;adding the half value of the cluster
  ;to the cluster value itself:
  ;;
   mov eax,ebx  ;Copy EBX
   shr eax,1    ;Divide by 2
   add eax,ebx  ;Add EBX to get 1+0.5 = 1.5
                ;with multiplicative effect

ret









;This function takes the byte offset
;of the FAT entry, which was
;created by "FAT12_cluster2fatEntry",
;to read and returns the actual
;value contained at that position:
;
;Inputs:
;
;      EAX = FAT offset
;      EBX = Cluster number
;
;Outputs:
;
;      EBX = FAT offset contents, of
;            the new cluster number.
;
;;
FAT12_readFATentry:
 push eax
 push edx


 ;Add the base address of our FAT "Heap",
 ;to our FAT offset in EAX:
 ;;
;  add eax,FAT12_FAT
   add eax,[FAT12_FAT_Start]


 ;Read the value a that entry:
 ;;
  xor edx,edx
  mov dx,[eax]


 ;We have read the entry, but
 ;now we must decide about how
 ;to clean it up:
 ;;

 ;See if the current cluster
 ;at BX is even or odd, by preserving
 ;only its bit 0:
 ;;
  and bl,1


 ;If EBX is 0, it means that the cluster
 ;number is even, and we must clean up
 ;the cluster value by ANDing with 0x0FFF
 ;to get rid from 4 bits of an adjacent
 ;FAT entry:
 ;;
  cmp bl,0
  je .cleanUpEven


   ;If EBX is 1, it means that the cluster
   ;number is odd, and we must clean up
   ;the cluster value by shifting it 4 bits
   ;to the right, to get rid from 4 bits
   ;(1/3) of an adjacent FAT entry:
   ;;
    .cleanUpOdd:
     shr edx,4
     jmp .endCleanup;




  .cleanUpEven:
    and edx,0x0FFF


 .endCleanup:


 ;Now that we have cleaned up
 ;the value, we put it in EBX
 ;to return it as a value:
 ;;
  mov ebx,edx

 pop edx
 pop eax
ret
