_KERN_START:
bits 32
org 1048576


cld
jmp __KERN_EntryPoint;


%include "strings.asm"
%include "misc.asm"


%include "CPU/x86-32/gdt.inc"
%include "CPU/x86-32/stack.inc"
%include "CPU/x86-32/idt.asm"
%include "CPU/x86-32/dummyISRs.asm"



%include "PIC_8259/remapIRQs.asm"
%include "PIC_8259/acknowledge.asm"


%include "PIT_8253_4/set_1ms.asm"
%include "PIT_8253_4/PIT_isr.asm"
%include "PIT_8253_4/install.asm"
%include "PIT_8253_4/waitTickChanges.asm"



%include "KBC_PS2_8042/utility.asm"
%include "KBC_PS2_8042/vars.asm"
%include "KBC_PS2_8042/install.asm"
%include "KBC_PS2_8042/KBC_PS2_isr.asm"


%include "KBC_PS2_8042/keyb/scancode_2.asm"
%include "KBC_PS2_8042/keyb/KB_ASCII_Print_Table.asm"
%include "KBC_PS2_8042/keyb/key_states.asm"


%include "KBC_PS2_8042/k_leds.asm"




%include "software/kern_console/vars.asm"
%include "software/kern_console/command_line_writer.asm"
%include "software/kern_console/command_line_interpreter.asm"
%include "software/kern_console/internal_commands_table.asm"
%include "software/kern_console/utility.asm"
%include "software/kern_console/print.asm"



%include "software/kern_lib/mem/utility.asm"
%include "software/kern_lib/mem/asciiz_buffers.asm"


%include "video/vga/textcursor.asm"


%include "software/kern_lib/string/find_nearest_byte.asm"


%include "FDC_82077_9/FDC_isr.asm"
%include "FDC_82077_9/vars.asm"
%include "FDC_82077_9/utility.asm"
%include "FDC_82077_9/install.asm"
%include "FDC_82077_9/FD.MAP"
%include "FDC_82077_9/FDD.INC"


%include "DMA_8237/fdc.asm"



%include "fs/fat12/fd/FDC_readSector_LBA.inc"
%include "fs/fat12/fd/vars.inc"
%include "fs/fat12/fd/createFATcache.inc"
%include "fs/fat12/fd/cluster2lba.inc"
%include "fs/fat12/fd/Floppy_FAT12_LBA_1.44_Table.inc"
%include "fs/fat12/fd/find_8_3_FileEntry.inc"
%include "fs/fat12/fd/lowercase2uppercase.inc"
%include "fs/fat12/fd/readFullFileClusterChain.inc"
%include "fs/fat12/fd/file_reader0.asm"


%include "dbg/FD6.inc"
%include "dbg/allMem.inc"



%include "software/kernel_exports/exported_functions.asm"
%include "software/kernel_exports/exported_variables.asm"

%include "software/raw_exes/raw_exe_header_defines.asm"



%include "KBC_PS2_8042/mouse/isr.asm"
%include "KBC_PS2_8042/mouse/install.asm"



%include "software/kern_lib/sys/reset.asm"



%include "software/kern_lib/cmdline/utility.asm"



%include "software/raw_exes/symbolRef2entrypoint.asm"
%include "software/raw_exes/resolveFunctionReferences.asm"




%include "software/LowEST/ioports/r.asm"
%include "software/LowEST/ioports/w.asm"

%include "software/LowEST/srcommon/console/arg2num.inc"
%include "software/LowEST/srcommon/console/arg2numwidth.inc"
%include "software/LowEST/srcommon/console/vars.asm"

%include "software/LowEST/srcommon/general/str/_tmp_prn_bindechex.inc"

%include "software/LowEST/srcommon/general/conv/bin2hex.inc"
%include "software/LowEST/srcommon/general/conv/num2str.inc"
%include "software/LowEST/srcommon/general/conv/str2num.inc"




align 4
__KERN_EntryPoint:



;;;;INIT: KERNEL.ASM Main Body
;;;;INIT: KERNEL.ASM Main Body
;;;;INIT: KERNEL.ASM Main Body
;;;;INIT: KERNEL.ASM Main Body
;;;;INIT: KERNEL.ASM Main Body
;;;;INIT: KERNEL.ASM Main Body



;The default action of our empty kernel
;will be to just halt the CPU:
;;
 cli



;Load a new GDT:
;;
 lgdt [GDT_x86_32]


;Reload Code Segment with a far jump:
;;
 jmp SELCod32:_CS_Reload0000
 align 4
 _CS_Reload0000:



;Reload segment selectors:
;;
 mov ax,SELDat32
 mov ds,ax
 mov es,ax
 mov fs,ax
 mov gs,ax
 mov ss,ax


;Reconfigure a new stack:
;;
   ;Take the address right after the kernel
   ;binary in memory, and place the start
   ;of the stack there:
   ;;
    mov eax,[_KERN_END]
    mov dword[StackStart],eax

   ;Add the desired size of the stack:
   ;;
    add eax,[StackSize]

   ;Take the opportunity to advance the
   ;kernel end mark:
   ;;
    mov [_KERN_END],eax

   ;Substract 1 to this value:
   ;;
    dec eax


   ;This is the end of our (inverted) stack.
   ;We must place this value in ESP:
   ;;
    mov esp,eax

 ;;;                                                      ;;;
 ;;;At this point, we can reliably start to call functions;;;
 ;;;and make use of the stack:                            ;;;
 ;;;;                                                    ;;;;


 ;Reprogram the PICs:
 ;;
  call PIC_8259__remapIRQs


 ;Create a default empty IDT:
 ;;
  call IDT_x86_32__createDefaultIDT


 ;Reconfigure the PIT and install its ISR:
 ;;
  call PIT_8253_4__Install


 ;Enable interrupts, since we need the PIT
 ;timing "services" to detect timeout errors
 ;for the rest of things we will configure,
 ;from this point on:
 ;;
  sti



 ;Reconfigure the PS/2 KBC and install the Keyboard ISR:
 ;;
  call KBC_PS2_8042__Configure_and_Install_Keyboard


 ;Reconfigure the PS/2 Mouse and install its ISR:
 ;;
  call KBC_PS2_8042__Configure_and_Install_Mouse




 ;Install the FDC interrupt handler and enable its IRQ.
 ;Later, we would probably need to do more initialization
 ;and detection tasks.
 ;;
  call FDC_82077_9__Install


 ;Print the OS identification in the console:
 ;;
  call kern_display_80x25_textVersion


;;;;END:  KERNEL.ASM Main Body
;;;;END:  KERNEL.ASM Main Body
;;;;END:  KERNEL.ASM Main Body
;;;;END:  KERNEL.ASM Main Body
;;;;END:  KERNEL.ASM Main Body
;;;;END:  KERNEL.ASM Main Body






;Infinite loop in which we will sit:
;;
 .ll:

  cmp byte[executer],1
  jne .noe

    call console_execute_command_line
    mov byte[executer],0

  .noe:


 jmp .ll









;What these lines do is:
;
;- First, it aligns the kernel image to 16 bytes,
;  to place the end-of-image "_KERN_END" variable,
;  in a more "predictable" place.
;
;- Then we actually create the "_KERN_END" variable.
;
;- We align the kernel image to 16 bytes again, by
;  using 12 bytes of padding plus the size of
;  our variable. It will actually make possible to
;  use this control variable and always assemble
;  a kernel image aligned to 16 bytes, which will
;  make dynamic creation of low level system structures,
;  right after the kernel, easier.
;
;
;NOTE: Since our image is assembled with a start
;      address of 1048576, first we must substract
;      it from '$', which represents the current
;      offset, from where we use it, into the program
;      image. So with ($-1048576), we get the actual
;      size of the kernel: an offset with base address of 0.
;
;;
 align 16
  _KERN_END_STATIC equ $+4+12
         _KERN_END  dd _KERN_END_STATIC
 align 16
