;/*
;
;Description:
;           "Write Immediate Value" to I/O port
;
;
;Usage under DOS/LowEST kernel:
;
;iow {byte|word|dword} {portnum} {immediate_value}
;
;
;Example:
;
;iow word 3f0h 34326
;
;     That example will:
;      write a word (2-byte port)
;      to port 3F0h
;      and will write the value 34326
;
;
;  All the arguments are mandatory. The port value
;  should be between 0 and FFFFh (65535), and the
;  address of the buffer pointer is a 32-bit value.
;
;  Calling this program with bogus values will yield
;  unpredictable results: use such bogus values only
;  if you want to do some hacking.
;
;*/

LowEST__iow:
 pusha

 ;See if we have the number of
 ;required arguments:
 ;;
  mov esi,console_command_line
  call getCommandLineArgsCount
  cmp eax,1+3
  jae .args_ok
   .errorstr:

   mov esi,iow__errorstr1
    call console_kprint_visible
    call console_doCRLFeffect

   mov esi,iow__errorstr2
    call console_kprint_visible
    call console_doCRLFeffect
    call console_doCRLFeffect

  jmp .exit
 .args_ok:




  xor ebp,ebp

 ;//Get parameter 1 -- {byte|word|dword}
 ;;
  mov edi,cmdline_copy
  mov ecx,1
  call copyCommandLineArg
  xchg esi,edi
  call sys_arg2numwidth
  xchg esi,edi


 ;If the specified length property wasn't valid,
 ;end with error:
 ;;
  cmp eax,0
  je .errorstr


 ;Save the result of parameter 1:
 ;;
  push eax


  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


 ;//Get parameter 2 -- {portnum}
 ;;
  mov edi,cmdline_copy
  mov ecx,2
  call copyCommandLineArg

 ;$EAX sys_arg2num($ESI argstring)
 ;;
  xchg esi,edi

   ;Convert this argument, from a binary,
   ;decimal or hexadecimal string, to
   ;a binary value, and put it in EDX,
   ;to serve as the I/O port number:
   ;;
    call sys_arg2num;
    mov edx,eax;

  xchg esi,edi





 ;//Get parameter 3 -- {immediate_value}
 ;;
  mov edi,cmdline_copy
  mov ecx,3
  call copyCommandLineArg

 ;$EAX sys_arg2num($ESI argstring)
 ;;
  xchg esi,edi

   ;Convert this argument, from a binary,
   ;decimal or hexadecimal string, to
   ;a binary value, and put it in EBX,
   ;to serve as the immediate value to write:
   ;;
    call sys_arg2num;
    mov ebx,eax;

  xchg esi,edi




  ;Restore the size value in EAX
  ;and put a copy of it in EBP:
  ;;
   pop eax
   mov ebp,eax




   ;This is for a BYTE read:
   ;;
    .switch_ln_81:
      cmp eax,11111111b
      jne .tryWord;
        xchg ebx,eax
        out dx,al
;        in al,dx
      jmp .switch_ln_81_end;


   ;This is for a WORD read:
   ;;
      .tryWord:
      cmp eax,1111111111111111b
      jne .tryDword;
        xchg ebx,eax
        out dx,ax
;        in ax,dx
      jmp .switch_ln_81_end;


   ;This is for a DWORD read:
   ;;
      .tryDword:
      cmp eax,11111111111111111111111111111111b
      jne .switch_ln_81_end;
        xchg ebx,eax
        out dx,eax
;        in eax,dx


    .switch_ln_81_end:



   ;Now print the value of the port to the screen,
   ;in binary, decimal and hexadecimal:
   ;;
;    call _tmp_prn_bindechex
;     call console_doCRLFeffect




 .exit:

 popa
ret


iow__errorstr1 db "Write Immediate Value to I/O Port",0
iow__errorstr2 db "Usage: IOW.com {byte|word|dword} {portnum} {immediate_value}",0
