;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;




;Inputs:
;      ESI == ASCIIZ string
;
;Outputs:
;      EAX == Offset of the first blank space, or 0
;             if the end of the string was reached.
;;
cmdLine__findFirstBlankSpace:
 push esi


 ;Assume we reached the end of the string:
 ;;
  mov eax,0


 .l:

  ;See if the current character is a null byte. If not,
  ;keep looping, since we haven't reached the end of the string:
  ;;
   cmp byte[esi],0
   je .l__END





  ;See if the current character is a blank space. If so,
  ;put its offset in EAX and end:
  ;;
   cmp byte[esi],' '
   jne .noSpace

        mov eax,esi
        jmp .l__END



   .noSpace:


  inc esi


  jmp .l  ;NOTE: I forgot this instruction and took me
          ;      2 days to find the problem. Now I know
          ;      how sneaky and hard to spot this kind
          ;      of error is, how much it can take to
          ;      find it, and the fact that it should be
          ;      at the top of my error-correcting
          ;      priorities, when I deal with any kind
          ;      of loops (seeing how this "loop" only
          ;      executed once, no matter if there was
          ;      no null character or blank spaces in
          ;      the string, etc...)
  .l__END:



 pop esi
ret































;Inputs:
;      ESI == ASCIIZ string
;
;Outputs:
;      EAX == Offset of the first non-blank space, or 0
;             if the end of the string was reached. This
;             function works through the notion that a command
;             line can, integrally, contain 3 main kinds of
;             of characters: Null, blank and non-blank.
;;
cmdLine__findFirstNonBlankSpace:
 push esi


 ;Assume we reached the end of the string:
 ;;
  mov eax,0


 .l:

  ;See if the current character is a null byte. If not,
  ;keep looping, since we haven't reached the end of the string:
  ;;
   cmp byte[esi],0
   je .l__END



  ;See if the current character is a non-blank space. If so,
  ;put its offset in EAX and end:
  ;;
   cmp byte[esi],' '
   je .Space

        mov eax,esi
        jmp .l__END

   .Space:


  inc esi


  jmp .l
  .l__END:


 pop esi
ret












































;Inputs:
;       ESI == Command line string
;
;
;Outputs:
;       EAX == Offset that strips off the 11-byte FAT file name
;              or 0 if there are no arguments in the command line
;
;This function just adds 11 to the command line to get rid of the
;raw short FAT file name, which could contain blank spaces; and
;then it looks for the first non-blank character.
;;
adjustCommandLineFATname:
 push esi


 ;First add 11:
 ;;
  add esi,11


 ;Now look for the first non-blank character, which is the actual
 ;start of the parameters:
 ;;
  call cmdLine__findFirstNonBlankSpace


 ;At this point, EAX contains either the position of the first
 ;non-blank space or 0, if there is no such non-blank character
 ;before the end of the string:
 ;;
  ;We have done all that we needed to do here...


 pop esi
ret













































































;Inputs:
;      ESI == ASCIIZ string
;
;Outputs:
;      EAX == Number of present parameters in the command line,
;             each other separated with blank spaces.
;;
getCommandLineArgsCount:
 push esi


 ;Create a stack variable -in- dword[esp]:
 ;                        paramCount=0
 ;
  push dword 0




;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;

 ;Do the loop, looking for non-blank blocks:
 ;;
  .l:


   ;See what kind of character we have at the current position:
   ;;
    ;Inputs:
    ;      ESI == ASCIIZ string
    ;      
    ;Outputs:
    ;
    ;      EAX == character tipe for a command line
    ;             0 -- null character
    ;             1 -- blank character
    ;             2 -- non-blank character
    ;
    ;;
     call cmdLine__charTypeAt


     ;If we got a null character, end:
     ;;
      cmp eax,0
      je .l__END


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

     ;If we got a blank character, skip as long as we keep getting
     ;blank characters:
     ;;
      cmp eax,1
      jne .noblank

       ;Inputs:
       ;         ESI == ASCIIZ string
       ;
       ;Outputs:
       ;         EAX == Position just after blank spaces, or 
       ;                unchanged if the current character was not
       ;                a blank space:
       ;;
        call cmdLine__skipBlankSpaces
        mov esi,eax
        jmp .l


      .noblank:


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

     ;If we got a non-blank character, account one more parameter,
     ;and skip as long as we keep getting non-blank characters:
     ;;
      cmp eax,2
      jne .nononblank

       ;Inputs:
       ;         ESI == ASCIIZ string
       ;
       ;Outputs:
       ;         EAX == Position just after non-blank characters, or 
       ;                unchanged if the current character was not
       ;                a non-blank character:
       ;;
        call cmdLine__skipNonBlankSpaces
        mov esi,eax

        inc dword[esp]
        jmp .l


      .nononblank:




;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;  jmp .l
  .l__END:
;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;







  ;Put the on-stack parameter count variable value
  ;in EAX and free up the used stack space (4 bytes):
  ;;
   mov eax,[esp]
   add esp,4

 pop esi
ret















































































;Inputs:
;       ESI == Command line string
;       EDI == String buffer to copy the argument to
;       ECX == Argument number (from 0)
;
;
;Outputs:
;       EAX == Nonzero if the argument was found, or 0 if the argument was not found
;
;;
copyCommandLineArg:
 push ecx
 push esi
 push edi


 ;See how many parameters there are in the command line:
 ;;
  call getCommandLineArgsCount


 ;See if the specified parameter is within the limits of
 ;the existing parameters:
 ;;
  cmp ecx,eax
  jb .withinLimits


    ;If we are here, the parameter number is invalid:
    ;;
     xor eax,eax
     jmp .END

  .withinLimits:



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


 ;Create a stack variable -in- dword[esp]:
 ;                        paramCount=0
 ;
  push dword 0




;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;

 ;Do the loop, looking for non-blank blocks:
 ;;
  .l:


   ;See what kind of character we have at the current position:
   ;;
    ;Inputs:
    ;      ESI == ASCIIZ string
    ;      
    ;Outputs:
    ;
    ;      EAX == character tipe for a command line
    ;             0 -- null character
    ;             1 -- blank character
    ;             2 -- non-blank character
    ;
    ;;
     call cmdLine__charTypeAt


     ;If we got a null character, end:
     ;;
      cmp eax,0
      je .l__END


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

     ;If we got a blank character, skip as long as we keep getting
     ;blank characters:
     ;;
      cmp eax,1
      jne .noblank

       ;Inputs:
       ;         ESI == ASCIIZ string
       ;
       ;Outputs:
       ;         EAX == Position just after blank spaces, or 
       ;                unchanged if the current character was not
       ;                a blank space:
       ;;
        call cmdLine__skipBlankSpaces
        mov esi,eax
        jmp .l


      .noblank:


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

     ;If we got a non-blank character, account one more parameter,
     ;and copy characters as long as we keep getting non-blank characters:
     ;;
      cmp eax,2
      jne .nononblank

       ;Inputs:
       ;         ESI == ASCIIZ string
       ;
       ;Outputs:
       ;         EAX == Position just after non-blank characters, or 
       ;                unchanged if the current character was not
       ;                a non-blank character:
       ;;
         ;See if we have reached the specified parameter:
         ;;
          cmp dword[esp],ecx


         ;If so, copy it.
         ;If not, skip the current parameter text, and
         ;keep looping in the main loop:
         ;;
          je .arrived

               ;Account one more parameter:
               ;;
                inc dword[esp]

               ;Skip the current parameter text to look for the
               ;next one:
               ;;
                call cmdLine__skipNonBlankSpaces
                mov esi,eax



               ;Keep looping:
               ;;
                jmp .l

         .arrived:



     ;----------------------------------------------------------------------------------
     ;----------------------------------------------------------------------------------
     ;----------------------------------------------------------------------------------
     ;----------------------------------------------------------------------------------
     ;----------------------------------------------------------------------------------
           ;If we are here, we have reached the asked-for
           ;parameter number and we must copy it.
           ;
           ;After copying it, we should end all loops and also
           ;mark the found/not found status of EAX:
           ;;
            .copyloop:




              ;See what kind of character we have at the current position:
              ;;
              ;Inputs:
              ;      ESI == ASCIIZ string
              ;      
              ;Outputs:
              ;
              ;      EAX == character tipe for a command line
              ;             0 -- null character
              ;             1 -- blank character
              ;             2 -- non-blank character
              ;
              ;;
               call cmdLine__charTypeAt


                ;See if our character is a non-blank character.
                ;If so, copy it; if not, stop all loops:
                ;;
                 cmp eax,2
                 jne .l__END

                   movsb


            jmp .copyloop
     ;----------------------------------------------------------------------------------
     ;----------------------------------------------------------------------------------
     ;----------------------------------------------------------------------------------
     ;----------------------------------------------------------------------------------
     ;----------------------------------------------------------------------------------


      .nononblank:

   jmp .l



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  .l__END:
;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;





  mov eax,1

  ;The last thing to do is to place a null character
  ;at the end of the command line parameter's copied substring:
  ;;
   mov byte[edi],0


  ;Free up the used stack space (4 bytes):
  ;;
   add esp,4


 .END:


 pop edi
 pop esi
 pop ecx
ret












;Inputs:
;      ESI == ASCIIZ string
;      
;Outputs:
;
;      EAX == character tipe for a command line
;             0 -- null character
;             1 -- blank character
;             2 -- non-blank character
;
;;
cmdLine__charTypeAt:
 
 ;Initialize EAX to 0:
 ;;
  xor eax,eax


 ;See if the current character is 0. If so,
 ;just end, since EAX is already 0 and that already
 ;indicates a null-type character:
 ;;
  cmp byte[esi],0
  jne .nonull
   jmp .END

  .nonull:



 ;If we are here, and the current character is
 ;either a blank space or a tab, mark EAX to 1,
 ;which means that the current chraracter is
 ;s blank-type character:
 ;;
  cmp byte[esi],' '
  je .space
  cmp byte[esi],'	'
  je .space
  jmp .nospace
   .space:

   mov al,1
   jmp .END

  .nospace:



 ;If we are here, it can only mean that the
 ;current character is any other one, and
 ;any other character is known as a
 ;non-blank type character:
 ;;
   mov al,2





 .END:


ret

























































;Inputs:
;         ESI == ASCIIZ string
;
;Outputs:
;         EAX == Position just after non-blank characters, or 
;                unchanged if the current character was not
;                a non-blank character:
;;
cmdLine__skipNonBlankSpaces:
 push esi


    .l:
      ;Inputs:
      ;      ESI == ASCIIZ string
      ;      
      ;Outputs:
      ;
      ;      EAX == character tipe for a command line
      ;             0 -- null character
      ;             1 -- blank character
      ;             2 -- non-blank character
      ;
      ;;
       call cmdLine__charTypeAt
       cmp eax,2
       jne .l__END


       inc esi
     jmp .l
     .l__END:



 mov eax,esi


 pop esi
ret


























































;Inputs:
;         ESI == ASCIIZ string
;
;Outputs:
;         EAX == Position just after blank characters, or 
;                unchanged if the current character was not
;                a blank character:
;;
cmdLine__skipBlankSpaces:
 push esi


    .l:
      ;Inputs:
      ;      ESI == ASCIIZ string
      ;      
      ;Outputs:
      ;
      ;      EAX == character tipe for a command line
      ;             0 -- null character
      ;             1 -- blank character
      ;             2 -- non-blank character
      ;
      ;;
       call cmdLine__charTypeAt
       cmp eax,1
       jne .l__END


       inc esi
     jmp .l
     .l__END:



 mov eax,esi


 pop esi
ret








;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
