System_Reset_Test_Loop:
 pusha

    ;WARNING:
    ;First attempt to handle Ctrl+Alt+Del.
    ;Note that this cannot handle the order
    ;in which keys are pressed, so we must
    ;create a formal procedure to detect
    ;a certain key precedence.
    ;
    ;E.g., Alt+Ctrl+Del and Ctrl+Alt+Del
    ;are valid Reset sequences, but
    ;Del+Alt+Ctrl or Del+Ctrl+Alt shouldn't,
    ;so we at least do something like this:
    ;
    ;Give these values:
    ;
    ;Shift = 2
    ;Ctrl  = 3
    ;Alt   = 4
    ;
    ;We must have 2 variables to detect Ctrl+Alt.
    ;When Ctrl and Alt are pressed, their values
    ;are summed from those variables, and when they
    ;are released, their values are substracted, down to 0.
    ;4+3 is 7, and in this context only that
    ;key combination can give us 7, so when these
    ;Ctrl_Key+Alt_Key variables are 7, when we press Del
    ;we must make sure that Ctrl_Key+Alt_Key is 7, so it
    ;won't matter that we press Ctrl+Alt or Alt+Ctrl
    ;(like the BIOS or Windows doesn't care either)
    ;but it will care that Del be the last key to
    ;be pressed since Del will ONLY cause a system reset
    ;if Ctrl_Key+Alt_Key is 7 by the time we press it.
    ;;
     ;Right or Left Ctrl:
     ;;
      mov esi,Keyboard_KeyStates
      cmp byte[esi+69],1
      je .doCTROL
      cmp byte[esi+70],1
      je .doCTROL
      jmp .noCTROL

      .doCTROL:

         ;If the state of any Ctrl key is 1 (pressed)
         ;we add 3 to Ctrl_Key, but ONLY if it isn't
         ;already 3:
         ;;
          mov byte[Ctrl_Key],3   ;Ctrl==3
          jmp .doCTRL__END


      .noCTROL:


        mov byte[Ctrl_Key],0   ;Ctrl==0


      .doCTRL__END:



     ;Left Alt or Right Alt (Alt Gr.):
     ;;
      mov esi,Keyboard_KeyStates
      cmp byte[esi+71],1
      je .doALT
      cmp byte[esi+72],1
      je .doALT
      jmp .noALT

      .doALT:

        mov byte[Alt_Key],4   ;Alt==4
        jmp .doALT__END


      .noALT:

        mov byte[Alt_Key],0   ;Alt==0


      .doALT__END:



     ;Del:
     ;;
      mov esi,Keyboard_KeyStates
      cmp byte[esi+73],1
      je .doDEL
      jmp .noDEL

      .doDEL:

        mov al,[Ctrl_Key]
        add al,[Alt_Key]

        cmp al,7   ;Ctrl+Alt==7
        jne .noDEL

        ;If we are here, it means that any of the 2 Ctrl and 2 Alt
        ;are being pressed, and we will reset:
        ;;
         inc byte[Ctrl_Alt_Del]


            cmp byte[Ctrl_Alt_Del],0
            je .noReset

               call console_doCRLFeffect
               mov esi,Resetting_through_KBC
                call console_kprint_visible
;                call console_doCRLFeffect  ;This is to not make look bad
                                           ;the outdated text cursor position
                                           ;and we keep it until we can
                                           ;move the cursor from
                                           ;console_kprint_visible




                  ;Wait until Commandable (empty input buffer)
                  ;;
                   .wait1:
                    in   al, 0x64
                    test al, 00000010b
                    jne  .wait1


                  ;Send SYSTEM RESET command to the keyboard controller:
                  ;;
                   mov  al, 0xFE
                   out  0x64, al

              ;This second "resseting" message should never
              ;be printed, but if it is, it will give us
              ;hits of how different machines react to
              ;a reset through the KBC:
              ;;
               call console_doCRLFeffect
               mov esi,Resetting_through_KBC
                call console_kprint_visible
;                call console_doCRLFeffect  ;This is to not make look bad
                                           ;the outdated text cursor position
                                           ;and we keep it until we can
                                           ;move the cursor from
                                           ;console_kprint_visible


            .noReset:

      .noDEL:



 popa
ret





